#!/bin/sh
#
# Name: bll
# Date: 2009-10-28 12:00
# Copyright: (C) 2009 Iskratel
# Author: Galkina Natalya <galkina@iskratel.si>
#
# Author: MontaVista Software, Inc. <source@mvista.com>
# Copyright: Copyright 1999-2003 MontaVista Software, Inc.
# License: 2003 (c) MontaVista Software, Inc. This file is licensed
#          under the terms of the GNU General Public License version 2.
#          This program is licensed "as is" without any warranty of any
#          kind, whether express or implied.
#
# Copyright 2002, 2003, 2004 Sony Corporation
# Copyright 2002, 2003, 2004 Matsushita Electric Industrial Co., Ltd.
#
#
### BEGIN INIT INFO
# Required-Start:
# Required-Stop:
# Should-Start:
# Should-Stop:
# Default-Start: 3
# Default-Stop: 0 1 2 4 5 6
# Short-Description: start/stop BLL daemon.
# Description: Start and stop Business Logic Layer deamon.
### END INIT INFO
# chkconfig: 3 40 10

# Init script information
INIT_NAME=blld
DHCPRA_NAME="dhcpra.bin"
PPPOEIA_NAME="pppoeia.bin"
DESC="Business Logic Layer daemon"
DAEMON_NAME="blld"
if [ "x${BRIDGE_SW_DIR}" != "x" ]; then
	PACKAGE_PATH=$BRIDGE_SW_DIR
else
	PACKAGE_PATH="/opt/si2000/neroot/active/bridge_SW"
fi
if [ "x${CLI_DIR}" != "x" ]; then
	CLI_PATH=$CLI_DIR
else
	CLI_PATH="/opt/si2000/neroot/active/cli"
fi
WORKING_DIR=$PACKAGE_PATH"/bin"
BOARD_TYPE=`fw_printenv boardid | sed -n 's/.*=//p' | cut -c1-3`

PID_FILE="/var/run/$DAEMON_NAME.pid"
DHCPRA_PID_FILE="/var/run/$DHCPRA_NAME.pid"
PPPOEIA_PID_FILE="/var/run/$PPPOEIA_NAME.pid"
CONFIG_DIR="/opt/si2000/neroot/active/etc/config"
CONFIG_FILE=$CONFIG_DIR"/config.scr"
NETPARMS_FILE=$CONFIG_DIR"/network_parms.scr"
SCRIPT_CHECK_PROG=$PACKAGE_PATH"/bin/itConfigCheck.sh"
BLL_SUPERVISOR=$PACKAGE_PATH"/bin/bllSupervisor.sh"
OO_INDICATOR=/opt/si2000/neroot/active/openolt_agent/bin/openolt
ISK_TIMESYNC_DIR="/opt/si2000/neroot/active/PTPms/bin"
ISK_TIMESYNC=$ISK_TIMESYNC_DIR"/iskTimeSync"
ISK_DPLL_CFG_PGM=$ISK_TIMESYNC_DIR"/zl303xx_PllCfg"
ISK_DPLL_CFG_FILE=$ISK_TIMESYNC_DIR"/zl303xx_freerun.mfg"

STOP_WAITING_LIMIT=15  # in seconds

##### dynamic_profiles_storage_module ####
DYNAMIC_CONFIG_FILE="/var/log/dynamic_profiles.scr"
##### dynamic_profiles_storage_module ####

COLOR_OK="\033[01;32m"   # Green
COLOR_FAIL="\033[01;31m" # Red
COLOR_WARN="\033[01;33m" # Yellow
COLOR_INFO="\033[01;36m" # Light blue
COLOR_RESET="\033[0m"    # Default

DONE_MSG=$COLOR_OK"Done."$COLOR_RESET
FAIL_MSG=$COLOR_FAIL"Failed."$COLOR_RESET

NETDEV_STARTER_LIMIT=1
NETDEV_RUNNING_LIMIT=300

export LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:/opt/si2000/neroot/active/lib

# Load init script configuration
[ -f /etc/default/$INIT_NAME ] && . /etc/default/$INIT_NAME

# Source the init script functions
. /etc/init.d/init-functions

# Test standalone flag provided by dhcp
# Test program ncfmCli returns:
#  0 - no standalone configuration
#  1 - standalone configuration

TEST_STANDALONE_PROG=/opt/iskratel/sbin/ncfmCli
TEST_STANDALONE_ARG="get std-flag"

ECFM_INFO=/etc/sysconfig/ecfm-info

# Read specific board info
if [ -e ${ECFM_INFO} ]; then
	. ${ECFM_INFO}
fi

BOOT_TYPE=/etc/sysconfig/boot-type-info

# Read specific board info
if [ -e ${BOOT_TYPE} ]; then
	. ${BOOT_TYPE}
fi

# Limit lo device if itmem_part is active.
[ -e /proc/net/itmem_part ] && {
	echo -n "Loopback MTU set to 1936... ";
	ifconfig lo mtu 1936;
	echo -e "${COLOR_OK}Done.${COLOR_RESET}";
}

##############################################################################
# Check if driver $1 is set to be loaded automatically. If it is not loaded
# yet then load it from $2. If $3 is set to "ignore" then don't return error
# in case of failure.
install_and_run_driver()
{
	if [ `grep $1 /etc/modules | wc -l` == 0 ]; then
		echo "$1" >> /etc/modules
	fi

	if [ `lsmod | grep $1 | wc -l` == 0 ]; then
		echo -e -n "Loading $1... "
		if [ "$BOARD_TYPE" == "SFI" ] || [ "$BOARD_TYPE" == "SPA" ] || [ "$BOARD_TYPE" == "SPB" ] || [ "$BOARD_TYPE" == "SPC" ] || [ "$BOARD_TYPE" == "SPD" ] || [ "$BOARD_TYPE" == "LS2" ] || [ "$BOARD_TYPE" == "SPE" ] || [ "$BOARD_TYPE" == "SPF" ] || [ "$BOARD_TYPE" == "SPG" ] || [ "$BOARD_TYPE" == "SPH" ] || [ "$BOARD_TYPE" == "SPI" ] || [ "$BOARD_TYPE" == "SPJ" ] || [ "$BOARD_TYPE" == "SPK" ]; then
			#Deps of the properly installed modules must be OK.
			modprobe $1
		else
			insmod /lib/modules/`uname -r`/kernel/$2 2>/dev/null
		fi
		if [ `lsmod | grep $1 | wc -l` == 0 ]; then
			if [ "$3" == "ignore" ]; then
				echo -e "${COLOR_WARN}Unable to load ${COLOR_INFO}$1${COLOR_RESET}.${COLOR_RESET}"
				return 0
			else
				echo -e $FAIL_MSG
				log_failure_msg " failed (error loading $1 kernel module)."
				return 1
			fi
		else
			echo -e $DONE_MSG
		fi
	fi
	return 0
}

enable_bridge()
{
	if [ `ifconfig br0 | grep UP | wc -l` == 0 ]; then
                echo -e -n "Disable brctl, use bridge_tool instead... "
                chmod -x /usr/sbin/brctl
		echo -e -n "Enabling bridge... "
		ifconfig br0 up 2>/dev/null
		if [ $? == 0 ]; then
			echo -e $DONE_MSG
#			if [ -f "$OO_INDICATOR" ]; then
				# Enable these 2 lines to enable CORD vSWitch
#				echo -e -n "Enabling CORD vSwitch switching mode... "
#				echo "switching_mode cord_vswitch" > /proc/net/itbridge/br0/bridge &

				# for now enable debug by default
#				echo "printk on" > /proc/net/itbridge/br0/tracer
#			fi
		else
			echo -e $FAIL_MSG
		fi
		if [ "$BOARD_TYPE" == "SPJ" ]; then
			[ -x /home/admin/config/topology_config.sh ] &&
				/home/admin/config/topology_config.sh& #temporary solution for hacking
		fi
	fi
}

# checkScriptFile(scriptFile):
#     Verifies checksum for 'scriptFile'.
#
#     @return 0 if checksum OK (or no checksum at the end of file or
#     if file does not exits at all), 3 if checksum is invalid, 2 or 1 on
#     any other errors.
#
#     @author afur
function checkScriptFile()
{
	if [[ $# -ne 1 ]]; then
		echo "FUBAR: checkScriptFile(): invalid number of parameters"
		exit 1
	fi

	local SCRIPT_FILE=$1

	if [[ -e $SCRIPT_FILE ]]; then
		$SCRIPT_CHECK_PROG --silent $SCRIPT_FILE
		local RET=$?
		return $RET
	fi
	return 0
}

# errMsgCheckScriptFile(scriptFile, errCode)
#     Output checksum verification error (for file 'scriptFile') message to
#     console and system logger. Error message printed depends on error
#     code 'errCode'.
#
#     @author afur
function errMsgCheckScriptFile()
{
	if [[ $# -ne 2 ]]; then
		echo "FUBAR: errMsgCheckScriptFile(): invalid number of parameters"
		exit 1
	fi
	local SCRIPT_FILE=$1
	local ERR_CODE=$2

	if [[ $ERR_CODE -eq 0 ]]; then
		return 0
	elif [[ $ERR_CODE -eq 3 ]]; then
		ERR_MSG="$SCRIPT_FILE: Invalid checksum. File modified manually?"
	else
		ERR_MSG="$SCRIPT_FILE: Error verifying checksum."
	fi
	ERR_MSG=$ERR_MSG" Will apply default configuration for this file."

	echo ""
	echo -en $COLOR_FAIL
	logger -s -p user.err -t "ERROR" $ERR_MSG
	echo -en $COLOR_RESET
	return 0
}

start_dhcpra()
{
	if [ -f $PACKAGE_PATH/bin/$DHCPRA_NAME ]; then
		echo -e -n "Starting $DHCPRA_NAME... "
		ulimit -s 250 -c 10000 && $PACKAGE_PATH/bin/$DHCPRA_NAME&
		RET=$?
		if [ $RET -eq 0 ]; then
			pidof $DHCPRA_NAME > $DHCPRA_PID_FILE
			echo -e $DONE_MSG
		else
			echo -e "$FAIL_MSG ($RET)"
			return 1
		fi
	fi
}

start_pppoeia()
{
	if [ -f $PACKAGE_PATH/bin/$PPPOEIA_NAME ]; then
		echo -e -n "Starting $PPPOEIA_NAME... "
		ulimit -s 250 -c 10000 && $PACKAGE_PATH/bin/$PPPOEIA_NAME &
		RET=$?
		if [ $RET -eq 0 ]; then
			pidof $PPPOEIA_NAME > $PPPOEIA_PID_FILE
			echo -e $DONE_MSG
		else
			echo -e "$FAIL_MSG ($RET)"
			return 1
		fi
	fi
}


startnet() {
	#rmmod mlinec_mod
	ifconfig eth0 up
	ifconfig eth0 down
	mng_tool add mng0
	bridge_tool add br1 2
	bridge_tool br1 if eth0
	bridge_tool br1 if mng0
	bridge_tool br1 localmac set mng0
	bridge_tool br1 addOnPort eth0 1
	ifconfig eth0 up
	ifconfig mng0 up
	echo "set_protected_port mng0 0" > /proc/net/itbridge/br1/bridge
	ifconfig br1 up

	# run DHCP client
	echo "Starting dhcp client ..."
	/etc/init.d/dhcpc start >> /tmp/dhcpc 2>&1
	if [ -e /etc/init.d/dhcpc6 ] ; then
		echo "Starting dhcp IPv6 client ..."
		/etc/init.d/dhcpc6 start >> /tmp/dhcpc6 2>&1
	fi
	return 0
}

stopnet() {
	ifconfig br1 down
	ifconfig eth0 down
	ifconfig mng0 0.0.0.0 down
	bridge_tool br1 dif mng0
	bridge_tool br1 dif eth0
	mng_tool del mng0

	#  stop DHCP client
	echo "Stopping dhcp client ..."
	/etc/init.d/dhcpc stop >> /tmp/dhcpc 2>&1
	if [ -e /etc/init.d/dhcpc6 ] ; then
		echo "Stopping dhcp IPv6 client ..."
		/etc/init.d/dhcpc6 stop >> /tmp/dhcpc 2>&1
	fi
	return 0
}

dummy() {
	echo
	echo -e  "*****************************************************************************"
	echo -e  "**                           Non BLL Mode                                  **"
	echo -e  "**                                                                         **"
	echo -e  "**   start BLL:              ${PACKAGE_PATH}/bin/blld.sh bll-on            **"
	echo -e  "**   stop  BLL:              ${PACKAGE_PATH}/bin/blld.sh bll-off           **"
	echo -e  "**   start NET:              ${PACKAGE_PATH}/bin/blld.sh net-on            **"
	echo -e  "**   stop  NET:              ${PACKAGE_PATH}/bin/blld.sh net-off           **"
	echo -e  "**   disable wdt and sysup:  ${PACKAGE_PATH}/bin/blld.sh supervision-stop  **"
	echo -e  "*****************************************************************************"
	stop_supervision
	return 0
}

reset_reason() {
	echo -e -n "Determining reset reason... "
	
	local RR=reset_reason
	local BLLD_SH=`readlink -f $PACKAGE_PATH//bin/$INIT_NAME.sh`
	local RR_DIR=`dirname $BLLD_SH`
	[ -x $RR_DIR/$RR.sh ] || { echo -e "$FAIL_MSG (no $RR_DIR/$RR.sh)"; return; }

	local VAR_LOG="/var/log"
	local SMALL_VAR_LOG_LEN=$((4*1024)) #4MB
	local SMALL_LOG_KB=10
	local LARGE_LOG_KB=100
	local RR_LOG_KB=$SMALL_LOG_KB
	local RR_OPTS="--minimal"

	local VL_SIZE=`df -k $VAR_LOG|tail -n1|awk '{print $2}'`
	if [ $VL_SIZE -gt $SMALL_VAR_LOG_LEN ]; then
		#when /var/log is > 4MB, use full version (with backtraces) and rotate files at 100 kB
		RR_LOG_KB=$LARGE_LOG_KB
		RR_OPTS=""
	fi

	#check size of log file
	local RR_MAX_LEN=$(($RR_LOG_KB*1024))  #10kB
	local SELF_ROTATE_MSG=`echo -e "\
*********************************************\n\
*** This is self-rotating file - 2x$RR_LOG_KB kB ***\n\
*********************************************"`
	local RR_LOG_FILE="$VAR_LOG/$RR.log"
	# 11.06.2018 modified by CMIL:REQ01162015
	# For SGT backup is on /temp dir for reset_reason and dsp
	if [ "$BOARD_TYPE" == "SGT" ]; then
		local TMP_RR=/temp/$RR.log
		if [ -e $TMP_RR ]; then
			cp $TMP_RR $RR_LOG_FILE 2>/dev/null
			cp $TMP_RR.1 $RR_LOG_FILE.1 2>/dev/null
		else
			cp $RR_LOG_FILE $TMP_RR 2>/dev/null
		fi
	fi
	local RR_SIZE=`ls -l $RR_LOG_FILE 2>/dev/null |awk '{print $5}'`
	[ "$RR_SIZE" = "" ] && RR_SIZE=0
	if [ $RR_SIZE -gt $RR_MAX_LEN ]; then
		mv $RR_LOG_FILE $RR_LOG_FILE.1 2>/dev/null
		if [ "$BOARD_TYPE" == "SGT" ]; then
			cp $RR_LOG_FILE.1 $TMP_RR.1 2>/dev/null
			rm -rf $TMP_RR 2>/dev/null
		fi
		RR_SIZE=0
	fi

	echo -e $DONE_MSG

	[ $RR_SIZE -eq 0 ] && echo "$SELF_ROTATE_MSG" | tee $RR_LOG_FILE $TMP_RR
	($RR_DIR/$RR.sh /var/log $RR_DIR/reset_reason_config.xml | tee -a $RR_LOG_FILE $TMP_RR) &   #do it in background
	# end CMIL
}

stop_supervision() {
	if [ "$BOARD_TYPE" == "SGT" ] || [ "$BOARD_TYPE" == "SFE" ]|| [ "$BOARD_TYPE" == "SFH" ] || [ "$BOARD_TYPE" == "SFD" ] || [ "$BOARD_TYPE" == "SGV" ] || [ "$BOARD_TYPE" == "DGA" ]; then
		return 0 # this feature is only avaliable on newer systems
	fi
	/opt/si2000/neroot/active/bridge_SW/bin/wdtkill.sh
	/opt/iskratel/bin/sysup-disable.sh disable krneki 0
	echo -e  "WDT & sysup are disabled"
	return 0
}


# Each init script action is defined below...
start() {
	local RET=0
	local APPLY_CONFIG=1

	# Start bll child process supervisor
	echo -e "Starting BLL supervisor..."
	$BLL_SUPERVISOR $BOARD_TYPE &

	chmod 644 $CLI_PATH/bin/cli.bin

	pidstatus "-p" "$PID_FILE" > /dev/null
	if [ "$ACTIVE_pids" != "" ]; then
		return 0;
	fi

	[ -e /etc/default/sys_profile ] && . /etc/default/sys_profile

	echo -e -n "Backup log files to _reset... "
	cp /var/log/messages /var/log/messages_reset 2>/dev/null
	cp /var/log/messages.1 /var/log/messages_reset.1 2>/dev/null
	cp /var/log/syslog /var/log/syslog_reset 2>/dev/null
	cp /var/log/syslog.1 /var/log/syslog_reset.1 2>/dev/null
	echo -e $DONE_MSG

	# find-out last reset reason
	reset_reason

	###################################################
	### Read board type...
	fw_printenv boardid | sed -n 's/.*=//p' &> /tmp/get_board_id
	
	chmod 444 /tmp/get_board_id
	local OLT_PORT_COUNT=`cat /tmp/get_board_id | cut -c9`

	###################################################
	# Temporary actions needed by DSL driver and bridge
	if [[ $BOARD_ID == SGR ]]; then
		# Check if character device exists
		if [ ! -e /dev/bcm6550aHpi ]; then
			echo -e -n "Creating '/dev/bcm6550aHpi'... "
			mknod /dev/bcm6550aHpi c 227 0
			if [ -e /dev/bcm6550aHpi ]; then
				echo -e $DONE_MSG
			else
				echo -e $FAIL_MSG
				return 1
			fi
		fi
	fi

	#########################################################
	#Staring microcode ######################################

	if [ "$BOARD_TYPE" == "SFI" ] || [ "$BOARD_TYPE" == "SPA" ] || [ "$BOARD_TYPE" == "SPB" ] || [ "$BOARD_TYPE" == "SPC" ] || [ "$BOARD_TYPE" == "SPD" ] || [ "$BOARD_TYPE" == "LS2" ] || [ "$BOARD_TYPE" == "SPE" ] || [ "$BOARD_TYPE" == "SPF" ] || [ "$BOARD_TYPE" == "SPG" ] || [ "$BOARD_TYPE" == "SPH" ] || [ "$BOARD_TYPE" == "SPI" ] || [ "$BOARD_TYPE" == "SPJ" ] || [ "$BOARD_TYPE" == "SPK" ]; then
		install_and_run_driver borea_pumaAPI extra/microcode/puma4/pumaAPI/borea_pumaAPI.ko

		if [ "$BOARD_TYPE" == "SPC" ] || [ "$BOARD_TYPE" == "SPD" ] || [ "$BOARD_TYPE" == "LS2" ] || [ "$BOARD_TYPE" == "SPE" ] || [ "$BOARD_TYPE" == "SPF" ] || [ "$BOARD_TYPE" == "SPG" ] || [ "$BOARD_TYPE" == "SPH" ] || [ "$BOARD_TYPE" == "SPI" ]; then
			if [ "$BOARD_TYPE" == "SPF" ] || [ "$BOARD_TYPE" == "SPG" ] || [ "$BOARD_TYPE" == "SPI" ]; then
				if [ $OLT_PORT_COUNT == 8 ]; then

					# if we have new FSL release 3.3 we must configure i40e differently
					lsbver=$(grep DISTRIB_RELEASE=3.3 /etc/lsb-release)
					if [ ! -z "$lsbver" ]
					then					
						modprobe i40e
						modprobe iavf
						
						for pciif in pci0 pci1 pci2 pci3
						do
							ethtool -K $pciif hw-tc-offload on					
							ethtool -K $pciif tx-udp-segmentation off
							ethtool -K $pciif rx-checksumming off
							ethtool -K $pciif tx-checksumming off
							ethtool -K $pciif scatter-gather off
							ethtool -K $pciif tcp-segmentation-offload off
							ethtool -K $pciif generic-segmentation-offload off
							ethtool -K $pciif generic-receive-offload off
							ethtool -K $pciif tx-gre-segmentation off
							ethtool -K $pciif tx-gre-csum-segmentation off
							ethtool -K $pciif tx-ipxip4-segmentation off
							ethtool -K $pciif tx-ipxip6-segmentation off
							ethtool -K $pciif tx-udp_tnl-segmentation off
							ethtool -K $pciif tx-udp_tnl-csum-segmentation off
							ethtool -K $pciif tx-gso-partial off
							ethtool -K $pciif ntuple-filters off							
							tc qdisc add dev $pciif root mqprio num_tc 8 map 0 1 2 3 4 5 6 7 queues 1@0 1@1 1@2 1@3 1@4 1@5 1@6 1@7 hw 1 mode channel
						done
					fi
				
					#init intel card before microcode
					echo 1 > /sys/class/net/pci0/device/sriov_numvfs
					sleep 2
					ip link set eth4 name maple2.1021
					# if we have new FSL release 3.3 we must configure i40e differently
					if [ ! -z "$lsbver" ]
					then
						ip link set pci0 vf 0 spoofchk off
						tc qdisc add dev maple2.1021 root mqprio num_tc 4 map 0 1 2 3  queues 1@0 1@1 1@2 1@3 hw 1 mode channel
					fi
					ifconfig pci0 up promisc
					ifconfig maple2.1021 up
					ip link set pci0 vf 0 vlan 1021

					ifconfig pci1 up promisc

					echo 1 > /sys/class/net/pci2/device/sriov_numvfs
					sleep 2
					ip link set eth4 name maple3.1021
					# if we have new FSL release 3.3 we must configure i40e differently
					if [ ! -z "$lsbver" ]
					then
						ip link set pci2 vf 0 spoofchk off
						tc qdisc add dev maple3.1021 root mqprio num_tc 4 map 0 1 2 3  queues 1@0 1@1 1@2 1@3 hw 1 mode channel
					fi
					ifconfig pci2 up promisc
					ifconfig maple3.1021 up
					ip link set pci2 vf 0 vlan 1021

					ifconfig pci3 up promisc

					for pciif in pci0 pci1 pci2 pci3
					do
						ethtool -K $pciif rxvlan off
						ethtool --pause $pciif rx on tx off
					done
				fi
			fi

			# Start puma ucode
			echo -e -n "Starting Puma ucode... "
			echo 1 > /sys/module/vfio_iommu_type1/parameters/allow_unsafe_interrupts
			echo vfio-fsl-mc > /sys/bus/fsl-mc/devices/dprc.3/driver_override
			echo dprc.3 > /sys/bus/fsl-mc/drivers/vfio-fsl-mc/bind

			if [ "$BOARD_TYPE" == "SPC" ]; then
				aiop_tool load -g dprc.3 -f /boot/puma4_AIOP-SPC.elf&
			elif [ "$BOARD_TYPE" == "SPD" ]; then
				aiop_tool load -g dprc.3 -f /boot/puma4_AIOP-SPD.elf&
				sleep 1
				ifconfig ethmux0 up
				ifconfig ethmux0 promisc
			elif [ "$BOARD_TYPE" == "SPE" ]; then
				aiop_tool load -g dprc.3 -f /boot/puma4_AIOP-SPE.elf&
			elif [ "$BOARD_TYPE" == "SPF" ]; then
				aiop_tool load -g dprc.3 -f /boot/puma4_AIOP-SPF.elf&
			elif [ "$BOARD_TYPE" == "SPG" ]; then
				aiop_tool load -g dprc.3 -f /boot/puma4_AIOP-SPG.elf&
			elif [ "$BOARD_TYPE" == "SPH" ]; then
				aiop_tool load -g dprc.3 -f /boot/puma4_AIOP-SPH.elf&
				sleep 1
				ifconfig ethmux0 up
				ifconfig ethmux0 promisc
			elif [ "$BOARD_TYPE" == "SPI" ]; then
				aiop_tool load -g dprc.3 -f /boot/puma4_AIOP-SPI.elf&
			fi
			sleep 10 #needed to initialize puma before uplink is up todo: make better solution than delay
			echo -e $DONE_MSG
		fi

		if [ "$BOARD_TYPE" == "SPJ" ] || [ "$BOARD_TYPE" == "SPK" ]; then
		   /boot/puma-start.sh spj
		fi
	fi

	# Load DPLL before Maple driver.
	if [ "$BOARD_TYPE" == "SPH" ] || [ "$BOARD_TYPE" == "SPI" ]; then
		if [ -f "$ISK_DPLL_CFG_PGM" ] && [ -f "$ISK_DPLL_CFG_FILE" ]; then
			cat > /tmp/isk_pllcfg_1.sh <<EOF
#!/bin/bash
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:/opt/si2000/neroot/active/PTPms/lib:.
$ISK_DPLL_CFG_PGM -r $ISK_DPLL_CFG_FILE>/dev/console 2>&1 >> /var/log/iskpllcfg.log
EOF
			chmod +x /tmp/isk_pllcfg_1.sh
			/tmp/isk_pllcfg_1.sh
			sleep 1
			echo -n -e "+++++ Setting DPLL in freerun mode... "
			echo "OK"
		fi
	fi

	#
	if [ "$BOARD_TYPE" == "SPH" ] || [ "$BOARD_TYPE" == "SPI" ]; then
		if [ -f "$ISK_TIMESYNC" ]; then
			echo -e -n "Starting Iskratel TimeSync process... "
			echo "$(date) Starting Iskratel TimeSync process... " >> /var/log/isktimesync.log
			cat > /tmp/isk_timesync_1.sh <<EOF
#!/bin/bash
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:/opt/si2000/neroot/active/PTPms/lib:/opt
nice -n -20 $ISK_TIMESYNC -d >/dev/console 2>&1 >> /var/log/isktimesync.log &

EOF
		  chmod +x /tmp/isk_timesync_1.sh
		  /tmp/isk_timesync_1.sh
		  sleep 1
		  echo "OK"
		fi
	fi


	if [ "$BOARD_TYPE" == "SPA" ] || [ "$BOARD_TYPE" == "SPB" ] || [ "$BOARD_TYPE" == "SPC" ] || [ "$BOARD_TYPE" == "SPD" ] || [ "$BOARD_TYPE" == "SPE" ] || [ "$BOARD_TYPE" == "SPF" ] || [ "$BOARD_TYPE" == "SPG" ] || [ "$BOARD_TYPE" == "SPH" ] || [ "$BOARD_TYPE" == "SPI" ]  || [ "$BOARD_TYPE" == "SPJ" ] || [ "$BOARD_TYPE" == "SPK" ]; then
		if [ "$BOARD_TYPE" == "SPA" ] || [ "$BOARD_TYPE" == "SPB" ] || [ "$BOARD_TYPE" == "SPC" ] || [ "$BOARD_TYPE" == "SPD" ] || [ "$BOARD_TYPE" == "SPH" ]; then
			# Maple drivers initialization.
			/opt/si2000/neroot/active/maple/bin/maple_init.sh
		fi 
		if [ "$BOARD_TYPE" == "SPJ" ] || [ "$BOARD_TYPE" == "SPK" ]; then
			# Maple drivers initialization.
			cd /opt/si2000/neroot/active/maple/bin
			./MapleUpgrade.sh 2
			cd -
			if [ "$BOARD_TYPE" == "SPJ" ]; then
				/opt/si2000/neroot/active/maple/bin/spj_init.sh
			elif [ "$BOARD_TYPE" == "SPK" ]; then
				/opt/si2000/neroot/active/maple/bin/spk_init.sh
			fi
		fi

		#Workaroud for maple innband boot. This clears maple internal memory.
		#if [ "$BOARD_TYPE" == "SPF" ] || [ "$BOARD_TYPE" == "SPG" ] || [ "$BOARD_TYPE" == "SPI" ]; then
		#	mv /opt/bcm68620/appl_settings.txt /opt/bcm68620/appl_settings.txtbak
		#	ln -s bcm68620_appl.bin /opt/bcm68620/appl_settings.txt
		#fi
		#end workaround

		# seting up interfaces for maple
		if [ "$BOARD_TYPE" == "SPE" ]; then
			cd /opt/si2000/neroot/active/maple/bin
			./MapleUpgrade.sh 4
			./Maple_Start.sh 1
			./Maple_Start.sh 2
			./Maple_Start.sh 3
			./Maple_Start.sh 4
			./spe_init.sh
			./spe_laser.sh&
		elif [ "$BOARD_TYPE" == "SPF" ]; then
			cd /opt/si2000/neroot/active/maple/bin
			if [ $OLT_PORT_COUNT == 8 ]; then
				./MapleUpgrade.sh 4
			else
				./MapleUpgrade.sh 2
			fi
			./Maple_Start.sh 1
			./Maple_Start.sh 2
			if [ $OLT_PORT_COUNT == 8 ]; then
				./Maple_Start.sh 3
				./Maple_Start.sh 4
			fi
		   ./spf_init.sh
		elif [ "$BOARD_TYPE" == "SPG" ]; then
			cd /opt/si2000/neroot/active/maple/bin
			if [ $OLT_PORT_COUNT == 8 ]; then
				./MapleUpgrade.sh 4
			else
				./MapleUpgrade.sh 2
			fi
			./Maple_Start.sh 1
			./Maple_Start.sh 2
			if [ $OLT_PORT_COUNT == 8 ]; then
				./Maple_Start.sh 3
				./Maple_Start.sh 4
			fi
			./spg_init.sh
		elif [ "$BOARD_TYPE" == "SPI" ]; then
			cd /opt/si2000/neroot/active/maple/bin
			if [ $OLT_PORT_COUNT == 8 ]; then
				./MapleUpgrade.sh 4
			else
				./MapleUpgrade.sh 2
			fi
			./Maple_Start.sh 1
			./Maple_Start.sh 2
			if [ $OLT_PORT_COUNT == 8 ]; then
				./Maple_Start.sh 3
				./Maple_Start.sh 4
			fi
			./spi_init.sh
		fi


		# starting maple daemon
		if [ "$BOARD_TYPE" == "SPE" ]; then
			/opt/si2000/neroot/active/maple/bin/bcm_maple_daemon -ud -dev_num 4 -dev_pon_ni 2 -dev_info 192.0.2.2:40005 -dev_info 192.0.2.6:40005 -dev_info 192.0.2.10:40005 -dev_info 192.0.2.14:40005
		elif [ "$BOARD_TYPE" == "SPF" ]; then
			if [ $OLT_PORT_COUNT == 8 ]; then
				/opt/si2000/neroot/active/maple/bin/bcm_maple_daemon -ud -dev_num 4 -dev_pon_ni 2 -dev_info 192.0.2.2:40005 -dev_info 192.0.2.6:40005 -dev_info 192.0.2.10:40005 -dev_info 192.0.2.14:40005
			else
				/opt/si2000/neroot/active/maple/bin/bcm_maple_daemon -ud -dev_num 2 -dev_pon_ni 2 -dev_info 192.0.2.2:40005 -dev_info 192.0.2.6:40005
			fi
		elif [ "$BOARD_TYPE" == "SPG" ]; then
			if [ $OLT_PORT_COUNT == 8 ]; then
				/opt/si2000/neroot/active/maple/bin/bcm_maple_daemon -ud -dev_num 4 -dev_pon_ni 2 -dev_info 192.0.2.2:40005 -dev_info 192.0.2.6:40005 -dev_info 192.0.2.10:40005 -dev_info 192.0.2.14:40005
			else
				/opt/si2000/neroot/active/maple/bin/bcm_maple_daemon -ud -dev_num 2 -dev_pon_ni 2 -dev_info 192.0.2.2:40005 -dev_info 192.0.2.6:40005
			fi
		elif [ "$BOARD_TYPE" == "SPI" ]; then
			if [ $OLT_PORT_COUNT == 8 ]; then
				/opt/si2000/neroot/active/maple/bin/bcm_maple_daemon -ud -dev_num 4 -dev_pon_ni 2 -dev_info 192.0.2.2:40005 -dev_info 192.0.2.6:40005 -dev_info 192.0.2.10:40005 -dev_info 192.0.2.14:40005
			else
				/opt/si2000/neroot/active/maple/bin/bcm_maple_daemon -ud -dev_num 2 -dev_pon_ni 2 -dev_info 192.0.2.2:40005 -dev_info 192.0.2.6:40005
			fi
		else
			/opt/si2000/neroot/active/maple/bin/bcm_maple_daemon >> /tmp/maple_log.txt
			/opt/si2000/neroot/active/bridge_SW/bin/bllMapleDdrDump.sh
		fi
		if [ $? -ne 0 ]; then
			echo -e -n "Error starting bcm_maple_daemon!"
			echo -e $FAIL_MSG
			return $?
		fi

		# Enable mutex_spin_on_owner() detector.
		if [ -f /proc/sys/kernel/mutex_spin_limit_pid ]; then
			local BMD_PID=`ps ax|awk '{if($5~/bcm_maple_daemon/) print $1;}'`
			echo $BMD_PID > /proc/sys/kernel/mutex_spin_limit_pid
			echo -e "mutex_spin_on_owner() monitor enabled for PID $BMD_PID."
		else
			echo -e "mutex_spin_on_owner() monitor not supported."
		fi
	fi

	#Workaroud for maple innband boot. This clears maple internal memory.
	#if [ "$BOARD_TYPE" == "SPF" ] || [ "$BOARD_TYPE" == "SPG" ] || [ "$BOARD_TYPE" == "SPI" ]; then
	#	FILE=/tmp/bllhapAddSeconds
	#	if test -f "$FILE"; then
	#		read i < $FILE
	#		j=`expr $i + 60`
	#		echo $j > $FILE
	#	else
	#		echo 60 > $FILE
	#	fi
	#	sleep 60
	#	rm -fr /opt/bcm68620/appl_settings.txt
	#	mv /opt/bcm68620/appl_settings.txtbak /opt/bcm68620/appl_settings.txt
	#fi
	#end workaround

	if [ "$BOARD_TYPE" == "SFE" ] || [ "$BOARD_TYPE" == "SFD" ]; then
		###################################################
		# Load both FPGA
		echo -e -n "Loading FPGA...."
		cat /boot/pl2tos3mii-35.bit > /dev/fpga0
		cat /boot/pl2tos3mii-35.bit > /dev/fpga1
		sleep 5
	fi

	if [ "$BOARD_TYPE" == "SFH" ]; then
		###################################################
		# Load both FPGA
		echo -e -n "Loading FPGA...."
		cat /boot/POSPHYtoSGMII_SFH_CoS.bit > /dev/fpga0
		cat /boot/POSPHYtoSGMII_SFH_CoS.bit > /dev/fpga1
		sleep 5
	fi

	#######################################################
	### Start rabbitMQ server
	#######################################################
	if [ "$BOARD_TYPE" == "SPC" ] || [ "$BOARD_TYPE" == "SPD" ] || [ "$BOARD_TYPE" == "SPE" ] || [ "$BOARD_TYPE" == "SPF" ] || [ "$BOARD_TYPE" == "SPG" ] || [ "$BOARD_TYPE" == "SPH" ] || [ "$BOARD_TYPE" == "SPI" ] || [ "$BOARD_TYPE" == "SPJ" ] || [ "$BOARD_TYPE" == "SPK" ]; then
		#only for debug purposes start web management
		#rabbitmq-plugins enable rabbitmq_management&
		#sleep 5
		#end web management
		RABBITMQ_NODENAME=rabbit@localhost rabbitmq-server start -detached 2>/dev/null &
		sleep 1
	fi


	###################################################
	### Install bridge kernel module
	if [ "$BOARD_TYPE" == "SFI" ] || [ "$BOARD_TYPE" == "SPA" ] || [ "$BOARD_TYPE" == "SPB" ] || [ "$BOARD_TYPE" == "SPC" ] || [ "$BOARD_TYPE" == "SPD" ] || [ "$BOARD_TYPE" == "LS2" ] || [ "$BOARD_TYPE" == "SPE" ] || [ "$BOARD_TYPE" == "SPF" ] || [ "$BOARD_TYPE" == "SPG" ] || [ "$BOARD_TYPE" == "SPH" ]  || [ "$BOARD_TYPE" == "SPI" ]  || [ "$BOARD_TYPE" == "SPJ" ] || [ "$BOARD_TYPE" == "SPK" ]; then
		install_and_run_driver itbridge_mod extra/itbridge/itbridge_mod.ko
	else
		install_and_run_driver itbridge_mod net/itbridge/itbridge_mod.ko
	fi
	if [ $? -ne 0 ]; then
		return $?
	fi

	### Install mng kernel module
	if [ "$BOARD_TYPE" == "SFI" ] || [ "$BOARD_TYPE" == "SPA" ] || [ "$BOARD_TYPE" == "SPB" ] || [ "$BOARD_TYPE" == "SPC" ] || [ "$BOARD_TYPE" == "SPD" ] || [ "$BOARD_TYPE" == "LS2" ] || [ "$BOARD_TYPE" == "SPE" ] || [ "$BOARD_TYPE" == "SPF" ] || [ "$BOARD_TYPE" == "SPG" ] || [ "$BOARD_TYPE" == "SPH" ] || [ "$BOARD_TYPE" == "SPI" ]  || [ "$BOARD_TYPE" == "SPJ" ] || [ "$BOARD_TYPE" == "SPK" ]; then
		install_and_run_driver itmng_mod extra/itmng/itmng_mod.ko
	else
		install_and_run_driver itmng_mod net/itmng/itmng_mod.ko
	fi
	if [ $? -ne 0 ]; then
		return $?
	fi

	### Install flow kernel module
	if [ "$BOARD_TYPE" == "SFI" ] || [ "$BOARD_TYPE" == "SPA" ] || [ "$BOARD_TYPE" == "SPB" ] || [ "$BOARD_TYPE" == "SPC" ] || [ "$BOARD_TYPE" == "SPD" ] || [ "$BOARD_TYPE" == "LS2" ] || [ "$BOARD_TYPE" == "SPE" ] || [ "$BOARD_TYPE" == "SPF" ]  || [ "$BOARD_TYPE" == "SPG" ] || [ "$BOARD_TYPE" == "SPH" ] || [ "$BOARD_TYPE" == "SPI" ]  || [ "$BOARD_TYPE" == "SPJ" ] || [ "$BOARD_TYPE" == "SPK" ]; then
		install_and_run_driver itflow_mod extra/itbridge/itflow_mod.ko
	else
		install_and_run_driver itflow_mod net/itbridge/itflow_mod.ko
	fi
	if [ $? -ne 0 ]; then
		return $?
	fi

	### Install igmp kernel module
	if [ "$BOARD_TYPE" == "SFI" ] || [ "$BOARD_TYPE" == "SPA" ] || [ "$BOARD_TYPE" == "SPB" ] || [ "$BOARD_TYPE" == "SPC" ] || [ "$BOARD_TYPE" == "SPD" ] || [ "$BOARD_TYPE" == "LS2" ] || [ "$BOARD_TYPE" == "SPE" ]  || [ "$BOARD_TYPE" == "SPF" ]  || [ "$BOARD_TYPE" == "SPG" ] || [ "$BOARD_TYPE" == "SPH" ] || [ "$BOARD_TYPE" == "SPI" ]  || [ "$BOARD_TYPE" == "SPJ" ] || [ "$BOARD_TYPE" == "SPK" ]; then
		install_and_run_driver itigmp_mod extra/itigmp/itigmp_mod.ko
	else
		install_and_run_driver itigmp_mod net/itigmp/itigmp_mod.ko
	fi
	if [ $? -ne 0 ]; then
		return $?
	fi


	### Install VDSL/IVE driver kernel modules
	BOARD_ID=`fw_printenv boardid | sed -r 's/^boardid=(...).+$/\1/'`
	if [[ $BOARD_ID == SGR ]]; then
		if [[ $(find /lib/modules/`uname -r`/kernel/drivers/ -name 'itvdsl2_mod.ko' | wc -l) -ne 0 ]]; then
			# Backward compatibility ...
			install_and_run_driver itvdsl2_mod drivers/itvdsl2/itvdsl2_mod.ko
			if [ $? -ne 0 ]; then return $?; fi
		else
			install_and_run_driver itvdsl2_bcm drivers/itvdsl2/bcm/itvdsl2_bcm.ko
			if [ $? -ne 0 ]; then return $?; fi

			if [[ `grep itvdsl2_mod /etc/modules | wc -l` -ne 0 ]]; then
				sed -i '/itvdsl2_mod/d' /etc/modules
			fi
		fi
	elif [[ $BOARD_ID == SGT ]]; then
		install_and_run_driver itvdsl2_ifxos drivers/itvdsl2/lantiq/ifxos/itvdsl2_ifxos.ko
		if [ $? -ne 0 ]; then return $?; fi

		install_and_run_driver itvdsl2_drvmei3 drivers/itvdsl2/lantiq/drvmei3/itvdsl2_drvmei3.ko
		if [ $? -ne 0 ]; then return $?; fi
	elif [[ $BOARD_ID == DGA ]]; then
		install_and_run_driver itvdsl2_ifxos drivers/itvdsl2/lantiq/ifxos/itvdsl2_ifxos.ko
		if [ $? -ne 0 ]; then return $?; fi

		install_and_run_driver itvdsl2_drvive drivers/itvdsl2/lantiq/drvive/itvdsl2_drvive.ko
		if [ $? -ne 0 ]; then return $?; fi
	elif [[ $BOARD_ID == SGV ]]; then
		install_and_run_driver itvdsl2_ifxos drivers/itvdsl2/lantiq/ifxos/itvdsl2_ifxos.ko
		if [ $? -ne 0 ]; then return $?; fi

		install_and_run_driver itvdsl2_drvmei3 drivers/itvdsl2/lantiq/drvmei3/itvdsl2_drvmei3.ko
		if [ $? -ne 0 ]; then return $?; fi

		install_and_run_driver itvdsl2_drvive drivers/itvdsl2/lantiq/drvive/itvdsl2_drvive.ko
		if [ $? -ne 0 ]; then return $?; fi
	fi

	### Run DGA IVE driver (temporary until BLL is ready to do this):
#	if [[ $BOARD_ID == DGA ]]; then
#		$PACKAGE_PATH/bin/itIveDriver_DGA.sh
#		if [ $? -ne 0 ]; then return $?; fi
#	fi

	### Run SGV VDSL and IVE drivers (temporary until BLL is ready to do this):
#	if [[ $BOARD_ID == SGV ]]; then
#		$PACKAGE_PATH/bin/itVdsl2Driver_SGV.sh
#		if [ $? -ne 0 ]; then return $?; fi
#
#		$PACKAGE_PATH/bin/itIveDriver_SGV.sh
#		if [ $? -ne 0 ]; then return $?; fi
#	fi


	### Install MLINEC kernel module
	if [ "$BOARD_TYPE" != "SPB" ]; then
		if [ "$BOARD_TYPE" == "SFI" ] || [ "$BOARD_TYPE" == "SPA" ] || [ "$BOARD_TYPE" == "SPB" ]; then
			install_and_run_driver mlinec_mod extra/itmlinec/mlinec_mod.ko ignore
		else
			install_and_run_driver mlinec_mod drivers/net/itmlinec/mlinec_mod.ko ignore
		fi
	fi

	### Install ARL kernel module
	if [ "$BOARD_TYPE" == "SFI" ] || [ "$BOARD_TYPE" == "SPA" ] || [ "$BOARD_TYPE" == "SPB" ] || [ "$BOARD_TYPE" == "SPC" ] || [ "$BOARD_TYPE" == "SPD" ] || [ "$BOARD_TYPE" == "LS2" ] || [ "$BOARD_TYPE" == "SPE" ] || [ "$BOARD_TYPE" == "SPF" ] || [ "$BOARD_TYPE" == "SPG" ] || [ "$BOARD_TYPE" == "SPH" ]  || [ "$BOARD_TYPE" == "SPI" ]  || [ "$BOARD_TYPE" == "SPJ" ] || [ "$BOARD_TYPE" == "SPK" ]; then
		install_and_run_driver arl_mod extra/afratelimit/arl_mod.ko ignore
	else
		install_and_run_driver arl_mod drivers/net/afratelimit/arl_mod.ko ignore
	fi


	###################################################
	### Migrations...
	local OLD_CONFIG_DIR="/etc/opt/config"
	
	if [[ -d $OLD_CONFIG_DIR && -n "`find $OLD_CONFIG_DIR -maxdepth 1 -name '*.scr'`" ]]; then
		if [[ -d $CONFIG_DIR && -n "`find $CONFIG_DIR -maxdepth 1 -name '*.scr'`" ]]; then
			echo "Found configuration scripts at both the old and the new location: the new location will be used."
		else
			echo -n "Found configuration scripts at the old location. Migrating... "
			if [[ ! -e $CONFIG_DIR ]]; then
				mkdir $CONFIG_DIR
			fi
			mv $OLD_CONFIG_DIR/*.scr $CONFIG_DIR
			if [[ $? -eq 0 ]]; then
				echo -e $DONE_MSG
			else
				echo -e $FAIL_MSG
			fi
		fi
	fi

	# Need to create config dir in any case if it still does not exist:
	if [[ ! -e $CONFIG_DIR ]]; then
		mkdir $CONFIG_DIR
	fi
	# Config dir needs to be group-writable (for admin user and CLI):
	chmod ug+w $CONFIG_DIR

	###################################################
	### Start FEA...
	if [ "$BOARD_TYPE" != "DGA" ]; then
		if [ ! -f "$OO_INDICATOR" ]; then
			start_dhcpra
			start_pppoeia
			echo -e "Starting BLL functions monitor ... "
			if [ "$BOARD_TYPE" != "SPJ" ] && [ "$BOARD_TYPE" != "SPK" ]; then
				[ -x $(dirname $0)/fe_monitor.sh ] && $(dirname $0)/fe_monitor.sh &
			fi
		fi
	fi

	###################################################
	### Start BLL...
	echo -e -n "Setting netdevice budget to $NETDEV_STARTER_LIMIT... "
	echo "$NETDEV_STARTER_LIMIT" > /proc/sys/net/core/netdev_budget
	echo -e $DONE_MSG

	echo -e -n "Testing PRODUCT_DIR... "
	if [ "$PRODUCT_DIR" != "" ]; then
		echo -e "$DONE_MSG ($PRODUCT_DIR)"
	elif [ -d /opt/si2000/neroot/active ]; then
		export PRODUCT_DIR="/opt/si2000/neroot/`readlink /opt/si2000/neroot/active`"
		echo -e "$DONE_MSG ($PRODUCT_DIR from /opt/si2000/neroot/active)"
	else
		echo -e "$FAIL_MSG (Not set)"
	fi

	echo -e -n "Starting $DESC: $DAEMON_NAME... "
	if [ "$BOARD_TWPE" == "SGR" ] || [ "$BOARD_TYPE" == "SGT" ] || [ "$BOARD_TYPE" == "SGV" ] || [ "$BOARD_TYPE" == "DGA" ] || [ "$BOARD_TYPE" == "SFE" ]|| [ "$BOARD_TYPE" == "SFH" ] || [ "$BOARD_TYPE" == "SFD" ]; then
		echo "1" >> /proc/sys/kernel/core_uses_pid
		echo "/tmp/core-%e-PID-%p-SIG-%s" > /proc/sys/kernel/core_pattern
	fi

	sysctl -w net.core.rmem_max=1000000
	ulimit -s 250 -c 10000 && start_daemon $PACKAGE_PATH/bin/$DAEMON_NAME
	RET=$?

	if [ $RET -eq 0 ]; then
		echo -e $DONE_MSG

		echo -e -n "Enable IPv6 on mng0 and ont0 devices"
		sysctl net.ipv6.conf.mng0.disable_ipv6=0
		sysctl net.ipv6.conf.ont0.disable_ipv6=0

		pidstatus "-p" "$PID_FILE" > /dev/null
		if [ "$ACTIVE_pids" = "" ]; then
			APPLY_CONFIG=0
		fi
		if [ -e ${TEST_STANDALONE_PROG} ]; then
			standalone_config=`${TEST_STANDALONE_PROG} ${TEST_STANDALONE_ARG}`
		else
			standalone_config=1
		fi
		# in case of old version of platform-utils
		if [ "x$standalone_config" = "x" ]; then
			standalone_config=1
		fi
		# Local configuration applied only in case standalone
	
		# Start SNMP agent
		#old path
		IT_SNMPD=/opt/si2000/neroot/active/bin/it-snmpd.sh
		#if old file not exist, try new path
		[ ! -e $IT_SNMPD ] && IT_SNMPD=/opt/si2000/neroot/active/bridge_SW/bin/it-snmpd.sh
		$IT_SNMPD start

		chmod 755 $CLI_PATH/bin/cli.bin

		if [ $APPLY_CONFIG -ne 0 -a "$standalone_config" -eq 1 ]; then
			echo -e -n "Applying CLI configuration... "
			sleep 5  # Does anyone know why this sleep is neccessary?

			# Verify both config files for manual changes (checksum verification).
			# If checksum fails, will later apply default config (empty file).
			checkScriptFile $NETPARMS_FILE
			RET=$?
			if [[ $RET -ne 0 ]]; then
				errMsgCheckScriptFile $NETPARMS_FILE $RET
				NETPARMS_FILE=`mktemp`  # is that elegant or what? :-)
			fi
			checkScriptFile $CONFIG_FILE
			RET=$?
			if [[ $RET -ne 0 ]]; then
				errMsgCheckScriptFile $CONFIG_FILE $RET
				CONFIG_FILE=`mktemp`   # is that elegant or what? :-)
			fi
			#### dynamic_profiles_storage_module ####
			checkScriptFile $DYNAMIC_CONFIG_FILE
			RET=$?
			if [[ $RET -ne 0 ]]; then
			   echo -e "$FAIL_MSG ($RET)"
			fi
			#### dynamic_profiles_storage_module ####

			# REQ01090048-urop: verify scripts separately, otherwise data about
			# faulty line number is lost
			#verify NETPARAMS script file
			if [[ -e $NETPARMS_FILE ]]; then
				$CLI_PATH/bin/cli -v $NETPARMS_FILE
				RET=$?
				if [ $RET -ne 0 ]; then
					echo -e "$FAIL_MSG ($RET)"
				fi
			fi

			#verify CONFIG script file
			if [[ -e $CONFIG_FILE ]]; then
				$CLI_PATH/bin/cli -v $CONFIG_FILE
				RET=$?
				if [ $RET -ne 0 ]; then
					echo -e "$FAIL_MSG ($RET)"
				fi
			fi

			### dynamic_profiles_storage_module ####
			#verify profile dynamic config script
			if [[ -e $DYNAMIC_CONFIG_FILE ]]; then
				$CLI_PATH/bin/cli -v $DYNAMIC_CONFIG_FILE
				RET=$?
				if [ $RET -ne 0 ]; then
					echo -e "$FAIL_MSG ($RET)"
				fi
			fi

			#### dynamic_profiles_storage_module ####

			# Concatenate both config files into a temporary file to apply
			# configuration, since currently there are problems
			# if pre/post apply-configuration events occur more than once.
			TMP_FULL_CONFIG=`mktemp`
			cat $NETPARMS_FILE > $TMP_FULL_CONFIG
			cat $CONFIG_FILE >> $TMP_FULL_CONFIG

			$CLI_PATH/bin/cli -s $TMP_FULL_CONFIG
			RET=$?
			if [ $RET -eq 0 ]; then
				echo -e $DONE_MSG
			fi
			rm $TMP_FULL_CONFIG
			# end REQ01090048-urop:
			
			#### dynamic_profiles_storage_module ####
			if [[ -e $DYNAMIC_CONFIG_FILE ]]; then
				sleep 10
				$CLI_PATH/bin/cli -sd $DYNAMIC_CONFIG_FILE
				RET=$?
				if [ $RET -eq 0 ]; then
					echo -e $DONE_MSG
				fi
			fi
			#### dynamic_profiles_storage_module ####
		else
			# in case 1IP temporary empty config is prepared and applied
			echo -e "Applying default configuration... "
			TMP_FULL_CONFIG=`mktemp`
			echo "" > $TMP_FULL_CONFIG
			$CLI_PATH/bin/cli -s $TMP_FULL_CONFIG
			rm -f $TMP_FULL_CONFIG
		fi

		if [ "$BOARD_TYPE" == "SPC" ] || [ "$BOARD_TYPE" == "SPD" ] || [ "$BOARD_TYPE" == "LS2" ] || [ "$BOARD_TYPE" == "SPE" ]  || [ "$BOARD_TYPE" == "SPF" ]  || [ "$BOARD_TYPE" == "SPG" ]  || [ "$BOARD_TYPE" == "SPH" ] || [ "$BOARD_TYPE" == "SPI" ]  || [ "$BOARD_TYPE" == "SPJ" ]|| [ "$BOARD_TYPE" == "SPK" ]; then
			# increase MTU for DSL and ETH interfaces
			for iface in $(ifconfig | cut -d ' ' -f1| tr ':' '\n' | awk NF | grep dsl); do
				ifconfig $iface mtu 1600
			done
			for iface in $(ifconfig | cut -d ' ' -f1| tr ':' '\n' | awk NF | grep eth); do
				ifconfig $iface mtu 1600
			done
		fi

		###################################################
		### Checking if serdes fail ....
		SERDES_FAIL=`fw_printenv serdes_fail | sed  's|.*=||'`
		if [ "x${SERDES_FAIL}" == "x1" ]; then 
			echo "Serdes is not properly initialised, rebooting ...."
			fw_setenv serdes_fail
			/opt/iskratel/bin/sysupReboot "Serdes not initialised" 3  &
		fi

		###################################################

		###################################################
		### Enable itBridge...
		enable_bridge

		###################################################
		### Start BAL...
#		if [ -f "$OO_INDICATOR" ]; then
#			echo -e -n "Starting BAL... "
#			cat > /tmp/bal.sh <<EOF
#cd /opt/si2000/neroot/active/maple/bin
#export BAL_DAEMON=y
#nice -n -20 taskset 0x01 ./bal_core_dist -C :55001 -M 127.0.0.1:5001 -S 127.0.0.1:5002 >/dev/console 2>&1 &
#EOF
#			chmod +x /tmp/bal.sh
#			/tmp/bal.sh
#			sleep 5
#			echo "OK"
#		fi

		###################################################
		### Start OpenOLT...
		if [ -f "$OO_INDICATOR" ]; then
			echo -e -n "Starting OpenOLT... "
			cat > /tmp/openolt.sh <<EOF
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:/opt/si2000/neroot/active/openolt_agent/lib
nice -n -20 taskset 0x01 /opt/si2000/neroot/active/openolt_agent/bin/openolt -C 127.0.0.1:55001 >/dev/console 2>&1 &
EOF
			chmod +x /tmp/openolt.sh
			/tmp/openolt.sh
			echo "OK"
		fi

		#all processes are started (and config applied), we can start monitor then
		kill -USR1 `ps ax | grep "bllSupervisor" | grep -v "grep" | cut -c1-6`

		# Temporary running DHCP client
		/etc/init.d/dhcpc start >> /tmp/dhcpc 2>&1
		if [ -e /etc/init.d/dhcpc6 ]; then
			/etc/init.d/dhcpc6 start >> /tmp/dhcpc6 2>&1
		fi
	else
		echo -e "$FAIL_MSG ($RET)"
		return 1
	fi

	# BLL and CLI passed. If no core will be dumped in next 10 sec, SW package is probably good.
	sleep 10;
	if [ `ls /tmp/core-* 2>/dev/null | wc -l` = 0 ]; then
		IT_CONTROL_END_CFG=/etc/default/it_control_end
		if [ -f ${IT_CONTROL_END_CFG} ]; then
			. ${IT_CONTROL_END_CFG}
			if [ ! "${IT_CONTROL_END_FILE}x" = "x" ]; then
				rm -f ${IT_CONTROL_END_FILE}
			fi
		fi
	fi

	# Start core dump monitor.
	echo -e -n "Starting core dump monitor... "
	while [ 1 ]; do [ `ls /tmp/core-* 2>/dev/null | wc -l` != 0 ] && echo -e "\033[01;31mThere are core dumps in /tmp.\033[0m" && rm -f /var/run/it_core_monitor.pid && exit 0; sleep 10; done &
	echo $! > /var/run/it_core_monitor.pid
	echo -e $DONE_MSG

	# Open bridge throttle.
	echo -e -n "Setting netdevice budget to $NETDEV_RUNNING_LIMIT... "
	echo "$NETDEV_RUNNING_LIMIT" > /proc/sys/net/core/netdev_budget
	echo -e $DONE_MSG

	if [ "$BOARD_TYPE" == "SPC" ] || [ "$BOARD_TYPE" == "SPD" ] || [ "$BOARD_TYPE" == "LS2" ] || [ "$BOARD_TYPE" == "SPE" ] || [ "$BOARD_TYPE" == "SPF" ] || [ "$BOARD_TYPE" == "SPG" ] || [ "$BOARD_TYPE" == "SPH" ] || [ "$BOARD_TYPE" == "SPI" ]  || [ "$BOARD_TYPE" == "SPJ" ] || [ "$BOARD_TYPE" == "SPK" ]; then
		# Start MC guard
		$PACKAGE_PATH/bin/monitor_mc_linkdown_issue.sh &
	fi

	# Start ES monitor.
	[ -x $(dirname $0)/es_monitor.sh ] && $(dirname $0)/es_monitor.sh &

	# Start cloning disk to finish rollback
	if [ -e /var/log/rollback_invoked ] && [ -e /sbin/system-clone ]; then
		/sbin/system-clone --rollback &
	fi

	#clear caches
	sync; echo 3 > /proc/sys/vm/drop_caches

	return 0
}

stop () {
	local RET=0
	local cnt=0
	local sleepPeriod=2
	local max=`expr $STOP_WAITING_LIMIT / $sleepPeriod`

	#old path
	IT_SNMPD=/opt/si2000/neroot/active/bin/it-snmpd.sh
	#if old file not exist, try new path
	[ ! -e $IT_SNMPD ] && IT_SNMPD=/opt/si2000/neroot/active/bridge_SW/bin/it-snmpd.sh
	$IT_SNMPD stop

	echo -e -n "Setting netdevice budget to $NETDEV_STARTER_LIMIT... "
	echo "$NETDEV_STARTER_LIMIT" > /proc/sys/net/core/netdev_budget
	echo -e $DONE_MSG

	echo -e -n "Stopping $DESC: $DAEMON_NAME... "
	killproc "-p" "$PID_FILE" "-15"
	RET=$?
	if [ $RET -eq 0 ]; then
		RET=1
		while [ "$cnt" -lt "$max" ]; do
			pidstatus "-p" "$PID_FILE" > /dev/null
			if [ "$ACTIVE_pids" = "" ]; then
				RET=0
				break;
			fi

			sleep "$sleepPeriod""s"
			cnt=`expr $cnt + 1`
		done
		if [ $RET -eq 0 ]; then
			echo -e $DONE_MSG
		else
			echo -e "Warning (Waiting period has expired. Daemon is stil running)."
		fi
	else
		echo -e "$FAIL_MSG ($RET: Unable to stop '$DAEMON_NAME'.)"
		return $RET
	fi

	if [ -e /var/run/it_core_monitor.pid ]; then
		echo -e -n "Stopping core dump monitor... "
		CORE_PID=`cat /var/run/it_core_monitor.pid`; kill -9 $CORE_PID > /dev/null 2>&1
		echo -e $DONE_MSG
	fi

	return 0
}

status() {
	local RET

	printstatus $DAEMON_NAME
	RET=$?

	return $RET
}

neton() {
	echo -e "Starting network ... "
	startnet
	return 0
}

netoff() {
	echo -e "Stopping network ... "
	stopnet
	return 0
}

hapdummy() {
	dummy
	return 0
}

#
# Everything after this should be the same for all init scripts
#
# See the policy manual for information on actions and return codes.
#

# cmil: REQ01215026 - Login prompt unification
echo "Iskratel" > /etc/hostname
hostname Iskratel
# end

parse() {
	case "$1" in
		bll-on)
			if [ `ifconfig mng0 2>&1 | grep "Device not found" | wc -l` == 0 ]; then
				echo "Network already established, BLL can't start, stop network or reboot system !"
				return $?
			fi
			echo "Setting bll on in boot environment, ..."
			fw_setenv bll on
			echo "Wait, BLL will start soon ..."
			return $?
			;;
		bll-off)
			echo "Setting bll off in boot environment, ..."
			fw_setenv bll off
			echo "Wait, BLL will stop soon ..."
			return $?
			;;
		status)
			status
			return $?
			;;
		net-on)
			if [ `ifconfig mng0 2>&1 | grep "Device not found" | wc -l` == 0 ]; then
				echo "Network already on !"
				return $?
			fi
			neton
			return $?
			;;
		net-off)
			if [ `ifconfig mng0 2>&1 | grep "Device not found" | wc -l` != 0 ]; then
				echo "Network already off !"
				return $?
			fi
			netoff
			return $?
			;;

		# BLL-HAP use only
		# old version
		start)
			start
			return $?
			;;
		stop)
			stop
			return $?
			;;
		 # new version
		hap-dummy)
			hapdummy
			return $?
			;;
		hap-start)
			start
			return $?
			;;
		hap-stop)
			stop
			return $?
			;;
		supervision-stop)
			kill -USR1 `ps ax | grep "bllSupervisor" | grep -v "grep" | cut -c1-6`
			stop_supervision
			return $?
			;;
		*)
			echo "Usage: $INIT_NAME.sh {bll-on|bll-off|status|net-on|net-off|supervision-stop}"
			;;
	esac

	return 1
}

parse $@
