#!/bin/sh
#
# Name: bllhap
# Date: 2010-01-04 12:00
# Author: MontaVista Software, Inc. <source@mvista.com> (ngal)
# Copyright: Copyright 1999-2003 MontaVista Software, Inc.
# License: 2003 (c) MontaVista Software, Inc. This file is licensed
#	   under the terms of the GNU General Public License version 2.
#	   This program is licensed "as is" without any warranty of any
#	   kind, whether express or implied.
#
# Copyright 2002, 2003, 2004 Sony Corporation
# Copyright 2002, 2003, 2004 Matsushita Electric Industrial Co., Ltd.
#
### BEGIN INIT INFO
# Required-Start:
# Required-Stop:
# Should-Start:
# Should-Stop:
# Default-Start: 3
# Default-Stop: 0 1 2 4 5 6
# Short-Description: start/stop BLL HAM proxy.
# Description: Start and stop Business Logic Layer proxy for High Availability Manager.
### END INIT INFO
# chkconfig: 3 75 70

# Init script information
INIT_NAME=bllp
DESC="Business Logic Layer HAM proxy"
DAEMON_NAME="bllhap"
if [ "x${BRIDGE_SW_DIR}" != "x" ]; then
	PACKAGE_PATH=$BRIDGE_SW_DIR
else
	PACKAGE_PATH="/opt/si2000/neroot/active"
fi

# Load init script configuration
[ -f /etc/default/$INIT_NAME ] && . /etc/default/$INIT_NAME

# Source the diagnostic environment variables
[ -f /etc/default/sys_profile ] && . /etc/default/sys_profile

# Source the init script functions
. /etc/init.d/init-functions



# Each init script action is defined below...

start() {
	local RET ERROR=

	#Start ISA 
	if [ -x /opt/si2000/neroot/isa/bin/isa ]; then
	        /opt/si2000/neroot/isa/bin/isa&
	else
		log_status_msg "Not starting ISA."
	fi
	
	log_status_msg "Starting $DESC: $DAEMON_NAME... " -n
	if [ -x $PACKAGE_PATH/bin/$DAEMON_NAME ]; then
		$PACKAGE_PATH/bin/$DAEMON_NAME start
		RET=$?
	else
		log_status_msg "MISSING EXECUTABLE: " -n
		RET=1
	fi

	if [ $RET -eq 0 ]; then
		log_success_msg " done. "
	else
		 log_failure_msg " failed ($RET: $ERROR)."
		 return 1
	fi

	log_status_msg ""
	return 0
}

stop () {
	local RET ERROR=

	log_status_msg "Stopping $DESC: $DAEMON_NAME... " -n
	$PACKAGE_PATH/bin/$DAEMON_NAME stop
	RET=$?

	if [ $RET -eq 0 ]; then
		log_success_msg " done. "
	else
		 log_failure_msg " failed ($RET: $ERROR)."
		 return 1
	fi

	log_status_msg ""
	return 0
}

#
# Everything after this should be the same for all init scripts
#
# See the policy manual for information on actions and return codes.
#

parse() {
	case "$1" in
		 start)
			  start
			  return $?
			  ;;
		 stop)
			  stop
			  return $?
			  ;;
		 restart)
			  restart
			  return $?
			  ;;
		 try-restart)
			  tryrestart
			  return $?
			  ;;
		 reload)
			  reload
			  return $?
			  ;;
		 force-reload)
			  forcereload
			  return $?
			  ;;
		 status)
			  status
			  return $?
			  ;;
		 *)
			  echo "Usage: $INIT_NAME " \
			  "{start|stop}" >&2
			  ;;
	esac

	return 1
}

parse $@


