#!/bin/sh
#
# Name: one_ip.sh
# Date: 2011-06-17
# Copyright: (C) 2009 Iskratel
# Author: Tomo Ceferin <tomo@metalab.si>
# Description: Monitor ES when in one-IP mode and reboot if connection lost.
# Execute: Executed by blld.sh script.
#

# Are we in "one IP" mode?
if [ `/opt/iskratel/sbin/ncfmCli get std-flag` == "0" ]; then
	# Some nice colors.
	COLOR_GREEN="\033[01;32m"
	COLOR_YELLOW="\033[01;33m"
	COLOR_RED="\033[01;31m"
	COLOR_RESET="\033[0m"

	# Settings.
	MISS_LIMIT=4
	MISS_SLEEP=5

	# Address to monitor.
	GW_ADDR="fe-float"

	# Wait for ES.
	echo -e "ES monitor: waiting for ES ($GW_ADDR)..."
	logger -p local0.notice "ES monitor: waiting for ES ($GW_ADDR)..."
	until ( ping -c 1 $GW_ADDR 1>/dev/null 2>/dev/null ); do
		sleep 1;
		[ `runlevel|awk '{print $2}'` -ne 3 ] && exit 0;
	done

	# We now have ES.
	echo -e "ES monitor: monitoring (drop after $MISS_LIMIT missed, check every $MISS_SLEEP seconds)..."
	logger -p local0.notice "ES monitor: monitoring (drop after $MISS_LIMIT missed, check every $MISS_SLEEP seconds)..."

	# Keep going until MISS_LIMIT pings have been missed.
	MISS_COUNT=0
	while [ $MISS_COUNT -lt $MISS_LIMIT ]; do
		sleep $MISS_SLEEP
		if [ `runlevel|awk '{print $2}'` -ne 3 ]; then
			echo -e "ES monitor: ${COLOR_GREEN}stopping (runlevel is `runlevel|awk '{print $2}'`)${COLOR_RESET}."
			logger -p local0.alert "ES monitor: stopping."
			exit 0;
		fi

		if (ping -c 1 $GW_ADDR 1>/dev/null 2>/dev/null); then
			[ $MISS_COUNT -ne 0 ] && echo -e "ES monitor: ${COLOR_GREEN}link back.${COLOR_RESET}" && logger -p local0.notice "ES monitor: link back."
			MISS_COUNT=0
		else
			MISS_COUNT=$(($MISS_COUNT+1))
			echo -e "ES monitor: ${COLOR_YELLOW}link lost ($MISS_COUNT/$MISS_LIMIT).${COLOR_RESET}"
			logger -p local0.notice "ES monitor: link lost ($MISS_COUNT/$MISS_LIMIT)."
		fi
	done

	# Log why we are going to reboot.
	echo -e "ES monitor: ${COLOR_RED}resetting the board${COLOR_RESET}."
	logger -p local0.alert "ES monitor: resetting the board."

	# Reboot this board.
	reboot
else
	echo -e "ES monitor: will not run (not in one-IP mode)."
fi
