#!/bin/sh

# Init script information
INIT_NAME=blld
IGMP_NAME="igmp.bin"
DHCPRA_NAME="dhcpra.bin"
PACKAGE_PATH="/opt/si2000/neroot/active"
WORKING_DIR=$PACKAGE_PATH"/bin"

IGMP_PID_FILE="/var/run/$IGMP_NAME.pid"
DHCPRA_PID_FILE="/var/run/$DHCPRA_NAME.pid"
CONFIG_DIR="/opt/si2000/neroot/active/etc/config"
CONFIG_FILE=$CONFIG_DIR"/config.scr"
NETPARMS_FILE=$CONFIG_DIR"/network_parms.scr"
SCRIPT_CHECK_PROG="/opt/si2000/neroot/active/bin/itConfigCheck.sh"
IGMP_RESTART_FLAG="/tmp/igmp_restart"  
DHCPRA_RESTART_FLAG="/tmp/dhcpra_restart" 

STOP_WAITING_LIMIT=15  # in seconds

COLOR_OK="\033[01;32m"   # Green
COLOR_FAIL="\033[01;31m" # Red
COLOR_WARN="\033[01;33m" # Yellow
COLOR_INFO="\033[01;36m" # Light blue
COLOR_RESET="\033[0m"    # Default

DONE_MSG=$COLOR_OK"Done."$COLOR_RESET
FAIL_MSG=$COLOR_FAIL"Failed."$COLOR_RESET

NETDEV_STARTER_LIMIT=1
NETDEV_RUNNING_LIMIT=300

RESTART_TYPE_RESTART=1
RESTART_TYPE_REBOOT=2

RESTART_TYPE=RESTART_TYPE_REBOOT

export LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:/opt/si2000/neroot/active/lib

# Load init script configuration
[ -f /etc/default/$INIT_NAME ] && . /etc/default/$INIT_NAME

# Source the init script functions
. /etc/init.d/init-functions

start_dhcpra()
{
    echo -e -n "Starting $DHCPRA_NAME... "
    ulimit -s 250 -c 10000 && $PACKAGE_PATH/bin/$DHCPRA_NAME&
    RET=$?
    if [ $RET -eq 0 ]; then
        pidof $DHCPRA_NAME > $DHCPRA_PID_FILE
        echo -e $DONE_MSG
    else
        echo -e "$FAIL_MSG ($RET)"
        return 1
    fi
}

start_igmp()
{
    echo -e -n "Starting $IGMP_NAME... "
    ulimit -s 250 -c 10000 && $PACKAGE_PATH/bin/$IGMP_NAME&
    RET=$?
    if [ $RET -eq 0 ]; then
        pidof $IGMP_NAME > $IGMP_PID_FILE
        echo -e $DONE_MSG
    else
        echo -e "$FAIL_MSG ($RET)"
        return 1
    fi
}

################################################
#      BLL function entity monitoring          #
################################################
#
### Start BLL FE
#
RESTART=0

while [ 1 ];  do
  ### igmp restart request ?
  if [ `ls $IGMP_RESTART_FLAG 2>/dev/null | wc -l` != 0 ]; then 
    echo -e $COLOR_FAIL"There is $IGMP_NAME restart request in /tmp."$COLOR_RESET 
    pidstatus "-p" "$IGMP_PID_FILE" > /dev/null
    if [ "$ACTIVE_pids" ]; then
        logger "Igmp restart request, killing $IGMP_NAME ..." 
        killproc "-p" "$IGMP_PID_FILE" "-15"
    fi    
    if [ $RESTART_TYPE = RESTART_TYPE_RESTART ]; then    
      logger "Igmp restart request, restarting $IGMP_NAME ..." 
      start_igmp
    else
      logger "Igmp restart request, system reboot ..." 
    fi
    rm  $IGMP_RESTART_FLAG 
    RESTART=$RESTART_TYPE  
  fi        
    
  ### dhcpra restart request ?
  if [ `ls $DHCPRA_RESTART_FLAG 2>/dev/null | wc -l` != 0 ]; then 
    echo -e $COLOR_FAIL"There is $DHCPRA_NAME restart request in /tmp."$COLOR_RESET 
    pidstatus "-p" "$DHCPRA_PID_FILE" > /dev/null
    if [ "$ACTIVE_pids" ]; then
        logger "Dhcpra restart request, killing $DHCPRA_NAME ..."
        killproc "-p" "$DHCPRA_PID_FILE" "-15"
    fi    
    if [ $RESTART_TYPE = RESTART_TYPE_RESTART ]; then    
      logger "Dhcpra restart request, restarting $DHCPRA_NAME ..."
      start_dhcpra
    else
      logger "Dhcpra restart request, system reboot ..." 
    fi
    rm  $DHCPRA_RESTART_FLAG 
    RESTART=$RESTART_TYPE      
  fi  
  
  if [ $RESTART = RESTART_TYPE_RESTART ]; then    
    sleep 5
    echo -e -n "Clearing configuration after BLE function restart... "
    $PACKAGE_PATH"/bin/cli" -c
    RET=$?                      
    if [ $RET -eq 0 ]; then
      echo -e $DONE_MSG
    else
      echo -e "$FAIL_MSG ($RET)"
      logger "Clearing configuration after BLE function restart failed, system reboot ..."
      reboot
    fi
    sleep 1
    echo -e -n "Applying CLI configuration after BLE function restart... "
    $PACKAGE_PATH"/bin/cli" -s $CONFIG_FILE
    RET=$?                      
    if [ $RET -eq 0 ]; then
      echo -e $DONE_MSG
    else
      echo -e "$FAIL_MSG ($RET)"
      logger "Applying CLI configuration after BLE function restart failed, system reboot ..."
      reboot
    fi  
    RESTART=0         
  fi
  
  if [ $RESTART = RESTART_TYPE_REBOOT ]; then   
    sleep 1
    reboot
  fi
  
  sleep 10; 
done
echo -e $DONE_MSG
