#!/bin/bash 
###########################################################################
#                                                                         #
#                                                                         #
#              Copyright (c) 2021 IskraTEL                                #
#                                                                         #
#                                                                         #
#                                                                         #
#   Name        : syslog_messages.sh                                      #
#                                                                         #
#   Description : Shell script for setting config file syslog-ng.conf     #
#                 for messages file                                       #
#                                                                         #
#   Position    : $PRODUCT_DIR/bin/                                       #
#                                                                         #
#   Code        :                                                         #
#                                                                         #
#   Date        : Feb 2021                                                #
#                                                                         #
#   Author      : Branko Zebec                                            #
#                                                                         #
#   Translation : * None                                                  #
#                                                                         #
#   Remarks     :                                                         #
#                                                                         #
#   Revisions   :                                                         #
#                                                                         #
###########################################################################


###################################################
#                                                 #	
# System parameters, path to commands and files   #
#                                                 #
###################################################

################
# Executables  #
################
AWK=awk
SED=sed

#######################
# System config files #
#######################
SYSLOGCONF=/etc/syslog-ng/syslog-ng.conf
SEARCH="filter f_messages"
REPLACE=$1
LEVELVALID=false


#check for valid level
checkLevel() {
  if [[ $1 == emerg ]]
  then
    LEVELVALID=true
  elif [[ $1 == alert ]]
  then
    LEVELVALID=true
  elif [[ $1 == crit ]]
  then
    LEVELVALID=true
  elif [[ $1 == err ]]
  then
    LEVELVALID=true
  elif [[ $1 == warning ]]
  then
    LEVELVALID=true
  elif [[ $1 == notice ]]
  then
    LEVELVALID=true
  elif [[ $1 == info ]]
  then
    LEVELVALID=true
  elif [[ $1 == debug ]]
  then
    LEVELVALID=false
  else
    LEVELVALID=false
  fi
}

#search a string $SEARCH in the file $SYSLOGCONF
#and then replace another string $REPLACE after that position
replaceLevel() {
  $SED  -e "/${SEARCH}/ s/level(emerg/level(${REPLACE}/;" -i $SYSLOGCONF
  $SED  -e "/${SEARCH}/ s/level(alert/level(${REPLACE}/;" -i $SYSLOGCONF
  $SED  -e "/${SEARCH}/ s/level(crit/level(${REPLACE}/;" -i $SYSLOGCONF
  $SED  -e "/${SEARCH}/ s/level(err/level(${REPLACE}/;" -i $SYSLOGCONF
  $SED  -e "/${SEARCH}/ s/level(warning/level(${REPLACE}/;" -i $SYSLOGCONF
  $SED  -e "/${SEARCH}/ s/level(notice/level(${REPLACE}/;" -i $SYSLOGCONF
  $SED  -e "/${SEARCH}/ s/level(info/level(${REPLACE}/;" -i $SYSLOGCONF
}

checkLevel $REPLACE

#replace level only if valid
if [[ $LEVELVALID == true ]]
then
  replaceLevel $REPLACE
else
  exit 1
fi

exit 0



